@@ -1,9 +1,9 @@
 package Treex::Core::Files;
 BEGIN {
-  $Treex::Core::Files::VERSION = '0.08157';
+  $Treex::Core::Files::VERSION = '0.08397';
 }
 use Moose;
-use MooseX::SemiAffordanceAccessor;
+use MooseX::SemiAffordanceAccessor 0.09;
 use Treex::Core::Log;
 use autodie;
 use File::Slurp 9999.19;
@@ -83,7 +83,7 @@ Treex::Core::Files - helper class for iterating over filenames
 
 =head1 VERSION
 
-version 0.08157
+version 0.08397
 
 =head1 SYNOPSIS
 
